@@ -1,10 +1,9 @@
-from django.conf import settings
 from sekizai.data import SekizaiDictionary
+from sekizai.helpers import get_varname
 
 def sekizai(request=None):
     """
     Simple context processor which makes sure that the SekizaiDictionary is
     available in all templates.
     """
-    varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
-    return {varname: SekizaiDictionary()}
+    return {get_varname(): SekizaiDictionary()}
